<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>ActionPackData</name>
    <message>
        <location filename="../actions/actionpackdata/actionpackdata.h" line="82"/>
        <source>Data related actions</source>
        <translation>Actions liées aux données</translation>
    </message>
</context>
<context>
    <name>Actions::CopyFileDefinition</name>
    <message>
        <location filename="../actions/actionpackdata/actions/copyfiledefinition.h" line="44"/>
        <source>Source file</source>
        <translation>Fichier source</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/copyfiledefinition.h" line="45"/>
        <source>The file to copy</source>
        <translation>Le fichier à copier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/copyfiledefinition.h" line="47"/>
        <source>Choose the file</source>
        <translation>Choisissez le fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/copyfiledefinition.h" line="48"/>
        <location filename="../actions/actionpackdata/actions/copyfiledefinition.h" line="55"/>
        <source>All files (*.*)</source>
        <translation>Tous les fichiers (*.*)</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/copyfiledefinition.h" line="51"/>
        <source>Destination</source>
        <translation>Destination</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/copyfiledefinition.h" line="52"/>
        <source>The destination file</source>
        <translation>Le fichier de destination</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/copyfiledefinition.h" line="54"/>
        <source>Choose the destination file</source>
        <translation>Choisissez le fichier de destination</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/copyfiledefinition.h" line="58"/>
        <source>Unable to read source file</source>
        <translation>Impossible de lire le fichier source</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/copyfiledefinition.h" line="59"/>
        <source>Unable to write destination file</source>
        <translation>Impossible d&apos;écrire le fichier de destination</translation>
    </message>
</context>
<context>
    <name>Actions::CopyFileInstance</name>
    <message>
        <location filename="../actions/actionpackdata/actions/copyfileinstance.h" line="62"/>
        <source>Unable to read the source file &quot;%1&quot;</source>
        <translation>Impossible de lire de fichier source &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/copyfileinstance.h" line="70"/>
        <source>Unable to write to &quot;%1&quot;</source>
        <translation>Impossible d&apos;écrire vers &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>Actions::ReadBinaryFileDefinition</name>
    <message>
        <location filename="../actions/actionpackdata/actions/readbinaryfiledefinition.h" line="45"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readbinaryfiledefinition.h" line="46"/>
        <source>The file to read from</source>
        <translation>Le fichier à lire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readbinaryfiledefinition.h" line="48"/>
        <source>Choose the file</source>
        <translation>Choisissez le fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readbinaryfiledefinition.h" line="49"/>
        <source>All files (*.*)</source>
        <translation>Tous les fichiers (*.*)</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readbinaryfiledefinition.h" line="52"/>
        <source>Variable</source>
        <translation>Variable</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readbinaryfiledefinition.h" line="53"/>
        <source>The variable where to store the data</source>
        <translation>La variable où stocker les données</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readbinaryfiledefinition.h" line="56"/>
        <source>Unable to read file</source>
        <translation>Impossible de lire le fichier</translation>
    </message>
</context>
<context>
    <name>Actions::ReadBinaryFileInstance</name>
    <message>
        <location filename="../actions/actionpackdata/actions/readbinaryfileinstance.h" line="62"/>
        <source>Unable to read the file &quot;%1&quot;</source>
        <translation>Impossible de lire le fichier &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>Actions::ReadClipboardDefinition</name>
    <message>
        <location filename="../actions/actionpackdata/actions/readclipboarddefinition.h" line="45"/>
        <source>Variable</source>
        <translation>Variable</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readclipboarddefinition.h" line="46"/>
        <source>The variable where to save the current clipboard value</source>
        <translation>La variable où enregistrer la valeur actuelle du presse-papiers</translation>
    </message>
</context>
<context>
    <name>Actions::ReadEnvironmentVariableDefinition</name>
    <message>
        <location filename="../actions/actionpackdata/actions/readenvironmentdefinition.h" line="49"/>
        <source>Variable</source>
        <translation>Variable</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readenvironmentdefinition.h" line="50"/>
        <source>The variable used to store the selected information from your system environment</source>
        <translation>La variable utilisée pour stocker l&apos;information sélectionnée à partir de votre environnement système</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readenvironmentdefinition.h" line="53"/>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readenvironmentdefinition.h" line="54"/>
        <source>The environment read mode</source>
        <translation>Le mode de lecture de l&apos;environnement</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readenvironmentdefinition.h" line="63"/>
        <source>Environment Variable</source>
        <translation>Variable d&apos;environnement</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readenvironmentdefinition.h" line="64"/>
        <source>The specific environment variable to read</source>
        <translation>La variable d&apos;environnement à lire</translation>
    </message>
</context>
<context>
    <name>Actions::ReadEnvironmentVariableInstance</name>
    <message>
        <location filename="../actions/actionpackdata/actions/readenvironmentinstance.cpp" line="64"/>
        <source>The specified variable cannot be found in the system environment</source>
        <translation>La variable spécifiée ne peut pas être trouvée dans votre environnement système</translation>
    </message>
</context>
<context>
    <name>Actions::ReadIniFileDefinition</name>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifiledefinition.h" line="46"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifiledefinition.h" line="47"/>
        <source>The file to read from</source>
        <translation>Le fichier à lire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifiledefinition.h" line="49"/>
        <source>Choose the INI file</source>
        <translation>Choisissez le fichier INI</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifiledefinition.h" line="50"/>
        <source>INI files (*.ini);;All files (*.*)</source>
        <translation>Fichiers INI (*.ini);;Tous les fichiers (*.*)</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifiledefinition.h" line="53"/>
        <source>Section</source>
        <translation>Section</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifiledefinition.h" line="54"/>
        <source>The section name of the parameter</source>
        <translation>Le nom de section du paramètre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifiledefinition.h" line="57"/>
        <source>Parameter</source>
        <translation>Paramètre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifiledefinition.h" line="58"/>
        <source>The parameter name</source>
        <translation>Le nom du paramètre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifiledefinition.h" line="61"/>
        <source>Variable</source>
        <translation>Variable</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifiledefinition.h" line="62"/>
        <source>The variable where to store the data</source>
        <translation>La variable où stocker les données</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifiledefinition.h" line="65"/>
        <source>Unable to read file</source>
        <translation>Impossible de lire le fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifiledefinition.h" line="66"/>
        <source>Unable to find section</source>
        <translation>Impossible de trouver la section</translation>
    </message>
</context>
<context>
    <name>Actions::ReadIniFileInstance</name>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifileinstance.h" line="60"/>
        <source>Unable to read the file</source>
        <translation>Impossible de lire le fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifileinstance.h" line="67"/>
        <source>Unable to find the section named &quot;%1&quot;</source>
        <translation>Impossible de trouver la section nommée &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>Actions::ReadRegistryDefinition</name>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistrydefinition.h" line="46"/>
        <source>Key</source>
        <translation>Clef</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistrydefinition.h" line="47"/>
        <source>The registry key to read from</source>
        <translation>La clef de registre à lire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistrydefinition.h" line="52"/>
        <source>Subkey</source>
        <translation>Sous-clef</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistrydefinition.h" line="53"/>
        <source>The registry subkey to read from</source>
        <translation>La sous-clef du registre à lire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistrydefinition.h" line="56"/>
        <source>Value</source>
        <translation>Valeur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistrydefinition.h" line="57"/>
        <source>The value to read</source>
        <translation>La valeur à lire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistrydefinition.h" line="60"/>
        <source>Variable</source>
        <translation>Variable</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistrydefinition.h" line="61"/>
        <source>The variable where to save the value read from the registry</source>
        <translation>La variable où enregistrer la valeur lue à partir du registre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistrydefinition.h" line="64"/>
        <source>Cannot find subKey</source>
        <translation>Impossible de trouver la sous-clef</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistrydefinition.h" line="65"/>
        <source>Cannot find value</source>
        <translation>Impossible de trouver la valeur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistrydefinition.h" line="66"/>
        <source>Invalid value type</source>
        <translation>Type de valeur incorrect</translation>
    </message>
</context>
<context>
    <name>Actions::ReadRegistryInstance</name>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistryinstance.cpp" line="54"/>
        <source>Cannot find subKey &quot;%1&quot;</source>
        <translation>Impossible de trouver la sous-clef &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistryinstance.cpp" line="58"/>
        <source>Cannot find value &quot;%1&quot;</source>
        <translation>Impossible de trouver la valeur &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistryinstance.cpp" line="62"/>
        <source>Invalid value type</source>
        <translation>Type de valeur incorrect</translation>
    </message>
</context>
<context>
    <name>Actions::ReadTextFileDefinition</name>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfiledefinition.h" line="50"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfiledefinition.h" line="51"/>
        <source>The file you want to read</source>
        <translation>Le fichier à lire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfiledefinition.h" line="54"/>
        <source>Variable</source>
        <translation>Variable</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfiledefinition.h" line="55"/>
        <source>The variable where to save the text read from the file</source>
        <translation>La variable où enregistrer le texte lu à partir du fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfiledefinition.h" line="58"/>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfiledefinition.h" line="59"/>
        <source>The file read mode</source>
        <translation>Le mode de lecture du fichier</translation>
    </message>
    <message>
        <source>Selection mode</source>
        <translation type="obsolete">Mode de sélection</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfiledefinition.h" line="68"/>
        <source>First line</source>
        <translation>Première ligne</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfiledefinition.h" line="69"/>
        <source>The line where to start reading the file</source>
        <translation>Line à partir de laquelle lire le fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfiledefinition.h" line="74"/>
        <source>Last line</source>
        <translation>Dernière ligne</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfiledefinition.h" line="75"/>
        <source>The line where to stop reading the file</source>
        <translation>La ligne où arrêter de lire le fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfiledefinition.h" line="82"/>
        <source>Cannot read file</source>
        <translation>Impossible de lire le fichier</translation>
    </message>
</context>
<context>
    <name>Actions::ReadTextFileInstance</name>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfileinstance.cpp" line="50"/>
        <source>Invalid first line value : %1</source>
        <translation>Valeur de première ligne incorrecte : %1</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfileinstance.cpp" line="57"/>
        <source>Invalid last line value : %1</source>
        <translation>Valeur de dernière ligne incorrecte : %1</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfileinstance.cpp" line="64"/>
        <source>The first line has to be smaller than the last line</source>
        <translation>La première ligne doit être plus petite que la dernière</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfileinstance.cpp" line="73"/>
        <source>Cannot open file</source>
        <translation>Impossible d&apos;ouvrir le fichier</translation>
    </message>
</context>
<context>
    <name>Actions::WebDownloadDefinition</name>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="51"/>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="52"/>
        <source>The URL of the data to download</source>
        <translation>L&apos;URL des données à télécharger</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="55"/>
        <source>Destination</source>
        <translation>Destination</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="56"/>
        <source>The destination where to write the downloaded data</source>
        <translation>La destination des données téléchargées</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="65"/>
        <source>Variable</source>
        <translation>Variable</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="66"/>
        <source>The variable where to write the downloaded data</source>
        <translation>La variable où stocker les données téléchargées</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="75"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="76"/>
        <source>The file where to write the downloaded data</source>
        <translation>Le fichier où stocker les données téléchargées</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="78"/>
        <source>Choose the destination file</source>
        <translation>Choisissez le fichier de destination</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="79"/>
        <source>All files (*.*)</source>
        <translation>Tous les fichiers (*.*)</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="84"/>
        <source>Show progress</source>
        <translation>Afficher la progression</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="85"/>
        <source>Should the download progress be shown</source>
        <translation>Affiche ou non la progression du téléchargement</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="89"/>
        <source>Cannot write to file</source>
        <translation>Impossible d&apos;écrire vers le fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="90"/>
        <source>Download error</source>
        <translation>Erreur de téléchargement</translation>
    </message>
</context>
<context>
    <name>Actions::WebDownloadInstance</name>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloadinstance.cpp" line="70"/>
        <source>Invalid URL</source>
        <translation>URL invalide</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloadinstance.cpp" line="80"/>
        <source>Cannot write to file</source>
        <translation>Impossible d&apos;écrire vers le fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloadinstance.cpp" line="92"/>
        <source>Downloading</source>
        <translation>Téléchargement</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloadinstance.cpp" line="93"/>
        <source>Downloading...</source>
        <translation>Téléchargement...</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloadinstance.cpp" line="129"/>
        <source>Download error: %1</source>
        <translation>Erreur de téléchargement : %1</translation>
    </message>
</context>
<context>
    <name>Actions::WriteBinaryFileDefinition</name>
    <message>
        <location filename="../actions/actionpackdata/actions/writebinaryfiledefinition.h" line="45"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writebinaryfiledefinition.h" line="46"/>
        <source>The file to write to</source>
        <translation>Le fichier à écrire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writebinaryfiledefinition.h" line="48"/>
        <source>Choose the file</source>
        <translation>Choisissez le fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writebinaryfiledefinition.h" line="49"/>
        <source>All files (*.*)</source>
        <translation>Tous les fichiers (*.*)</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writebinaryfiledefinition.h" line="52"/>
        <source>Data</source>
        <translation>Données</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writebinaryfiledefinition.h" line="53"/>
        <source>The data to write to the file</source>
        <translation>Les données à écrire dans le fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writebinaryfiledefinition.h" line="56"/>
        <source>Unable to write to the file</source>
        <translation>Impossible d&apos;écrire vers le fichier</translation>
    </message>
</context>
<context>
    <name>Actions::WriteBinaryFileInstance</name>
    <message>
        <location filename="../actions/actionpackdata/actions/writebinaryfileinstance.h" line="63"/>
        <source>Unable to write to the file &quot;%1&quot;</source>
        <translation>Impossible d&apos;écrire vers le fichier &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>Actions::WriteClipboardDefinition</name>
    <message>
        <location filename="../actions/actionpackdata/actions/writeclipboarddefinition.h" line="45"/>
        <source>Value</source>
        <translation>Valeur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeclipboarddefinition.h" line="46"/>
        <source>The new clipboard value</source>
        <translation>La nouvelle valeur du presse-papier</translation>
    </message>
</context>
<context>
    <name>Actions::WriteIniFileDefinition</name>
    <message>
        <location filename="../actions/actionpackdata/actions/writeinifiledefinition.h" line="45"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeinifiledefinition.h" line="46"/>
        <source>The file to create or edit</source>
        <translation>Le fichier à créer ou à éditer</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeinifiledefinition.h" line="48"/>
        <source>Choose the INI file</source>
        <translation>Choisissez le fichier INI</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeinifiledefinition.h" line="49"/>
        <source>INI files (*.ini);;All files (*.*)</source>
        <translation>Fichiers INI (*.ini);;Tous les fichiers (*.*)</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeinifiledefinition.h" line="52"/>
        <source>Section</source>
        <translation>Section</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeinifiledefinition.h" line="53"/>
        <source>The section name of the parameter</source>
        <translation>Le nom de la section du paramètre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeinifiledefinition.h" line="56"/>
        <source>Parameter</source>
        <translation>Paramètre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeinifiledefinition.h" line="57"/>
        <source>The parameter name</source>
        <translation>Le nom du paramètre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeinifiledefinition.h" line="60"/>
        <source>Value</source>
        <translation>Valeur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeinifiledefinition.h" line="61"/>
        <source>The new value</source>
        <translation>La nouvelle valeur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeinifiledefinition.h" line="64"/>
        <source>Unable to write file</source>
        <translation>Impossible d&apos;écrire vers le fichier</translation>
    </message>
</context>
<context>
    <name>Actions::WriteIniFileInstance</name>
    <message>
        <location filename="../actions/actionpackdata/actions/writeinifileinstance.h" line="58"/>
        <source>Unable to write to the file</source>
        <translation>Impossible d&apos;écrire vers le fichier</translation>
    </message>
</context>
<context>
    <name>Actions::WriteRegistryDefinition</name>
    <message>
        <location filename="../actions/actionpackdata/actions/writeregistrydefinition.h" line="46"/>
        <source>Key</source>
        <translation>Clef</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeregistrydefinition.h" line="47"/>
        <source>The registry key to write to</source>
        <translation>La clef de registre à écrire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeregistrydefinition.h" line="52"/>
        <source>Subkey</source>
        <translation>Sous-clef</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeregistrydefinition.h" line="53"/>
        <source>The registry subkey to write to</source>
        <translation>La sous-clef de registre à écrire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeregistrydefinition.h" line="56"/>
        <source>Value</source>
        <translation>Valeur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeregistrydefinition.h" line="57"/>
        <source>The value to write to</source>
        <translation>La valeur où écrire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeregistrydefinition.h" line="60"/>
        <source>Data</source>
        <translation>Données</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeregistrydefinition.h" line="61"/>
        <source>The data to write</source>
        <translation>Les données à écrire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeregistrydefinition.h" line="64"/>
        <source>Cannot find subKey</source>
        <translation>Impossible de trouver la sous-clef</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeregistrydefinition.h" line="65"/>
        <source>Cannot write value</source>
        <translation>Impossible d&apos;écrire la valeur</translation>
    </message>
</context>
<context>
    <name>Actions::WriteRegistryInstance</name>
    <message>
        <location filename="../actions/actionpackdata/actions/writeregistryinstance.cpp" line="47"/>
        <source>Cannot find subKey &quot;%1&quot;</source>
        <translation>Impossible de trouver la sous-clef &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeregistryinstance.cpp" line="51"/>
        <source>Cannot write value &quot;%1&quot;</source>
        <translation>Impossible d&apos;écrire la valeur &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>Actions::WriteTextFileDefinition</name>
    <message>
        <location filename="../actions/actionpackdata/actions/writetextfiledefinition.h" line="48"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writetextfiledefinition.h" line="49"/>
        <source>The file you want to write</source>
        <translation>Le fichier à écrire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writetextfiledefinition.h" line="52"/>
        <source>Text</source>
        <translation>Texte</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writetextfiledefinition.h" line="53"/>
        <source>The text to write to the file</source>
        <translation>Le texte à écrire vers le fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writetextfiledefinition.h" line="56"/>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writetextfiledefinition.h" line="57"/>
        <source>The file write mode</source>
        <translation>Le mode d&apos;écriture du fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writetextfiledefinition.h" line="62"/>
        <source>Cannot write file</source>
        <translation>Impossible d&apos;écrire le fichier</translation>
    </message>
</context>
<context>
    <name>Actions::WriteTextFileInstance</name>
    <message>
        <location filename="../actions/actionpackdata/actions/writetextfileinstance.cpp" line="47"/>
        <source>Cannot open file</source>
        <translation>Impossible d&apos;ouvrir le fichier</translation>
    </message>
</context>
<context>
    <name>Code::Clipboard</name>
    <message>
        <location filename="../actions/actionpackdata/code/clipboard.cpp" line="123"/>
        <source>Selection mode is not supported by your operating system</source>
        <translation>Le mode sélection n&apos;est pas supporté par votre système d&apos;exploitation</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/clipboard.cpp" line="130"/>
        <source>Find buffer mode is not supported by your operating system</source>
        <translation>Le mode tampon de recherche n&apos;est pas supporté par votre système d&apos;exploitation</translation>
    </message>
</context>
<context>
    <name>Code::File</name>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="56"/>
        <location filename="../actions/actionpackdata/code/file.cpp" line="91"/>
        <location filename="../actions/actionpackdata/code/file.cpp" line="226"/>
        <source>Incorrect parameter count</source>
        <translation>Nombre de paramètres incorrect</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="131"/>
        <source>Unable to open file</source>
        <translation>Impossible d&apos;ouvrir le fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="142"/>
        <location filename="../actions/actionpackdata/code/file.cpp" line="147"/>
        <location filename="../actions/actionpackdata/code/file.cpp" line="156"/>
        <source>Write failed</source>
        <translation>L&apos;écriture a échouée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="288"/>
        <location filename="../actions/actionpackdata/code/file.cpp" line="384"/>
        <source>Unable to create destination directory</source>
        <translation>Impossible de créer le dossier de destination</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="294"/>
        <location filename="../actions/actionpackdata/code/file.cpp" line="390"/>
        <source>Destination directory doesn&apos;t exist</source>
        <translation>Le dossier de destination n&apos;existe pas</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="309"/>
        <source>Copy failed</source>
        <translation>Copie échouée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="347"/>
        <source>Copy failed: %1</source>
        <translation>Copie échouée : %1</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="353"/>
        <source>Copy failed: aborted</source>
        <translation>Copie échouée : annulée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="405"/>
        <source>Move/rename failed</source>
        <translation>Déplacement/renommage échoué</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="443"/>
        <source>Move failed: %1</source>
        <translation>Déplacement échoué : %1</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="449"/>
        <source>Move failed: aborted</source>
        <translation>Déplacement échoué : annulé</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="498"/>
        <source>Rename failed: %1</source>
        <translation>Renommage échoué : %1</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="504"/>
        <source>Rename failed: aborted</source>
        <translation>Renommage échoué : annulé</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="531"/>
        <source>Remove failed</source>
        <translation>Le suppression a échoué</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="563"/>
        <source>Remove failed: %1</source>
        <translation>Suppression échouée : %1</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="569"/>
        <source>Remove failed: aborted</source>
        <translation>Suppression échouée : annulée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="590"/>
        <source>File not found</source>
        <translation>Impossible de trouver le fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="592"/>
        <source>Path not found</source>
        <translation>Impossible de trouver le chemin</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="594"/>
        <source>Access denied</source>
        <translation>Accès refusé</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="596"/>
        <source>This file is used by another process</source>
        <translation>Ce fichier est utilisé par un autre processus</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="598"/>
        <source>The disk is full</source>
        <translation>Plus d&apos;espace disponible sur le disque</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="601"/>
        <source>The file already exists</source>
        <translation>Le fichier existe déjà</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="603"/>
        <source>Invalid name</source>
        <translation>Nom incorrect</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="605"/>
        <source>Canceled</source>
        <translation>Annulé</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/file.cpp" line="607"/>
        <source>Unknown error (%1)</source>
        <translation>Erreur inconnue (%1)</translation>
    </message>
</context>
<context>
    <name>Code::IniFile</name>
    <message>
        <location filename="../actions/actionpackdata/code/inifile.cpp" line="70"/>
        <source>Cannot load the file</source>
        <translation>Impossible de charger le fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/inifile.cpp" line="88"/>
        <source>Cannot save the file</source>
        <translation>Impossible d&apos;enregistrer le fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/inifile.cpp" line="127"/>
        <source>Cannot find the section named &quot;%1&quot;</source>
        <translation>Impossible de trouver la section nommée &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/inifile.cpp" line="145"/>
        <source>Invalid section index</source>
        <translation>Index de section incorrect</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/inifile.cpp" line="156"/>
        <source>Cannot delete section named &quot;%1&quot;</source>
        <translation>Impossible de supprimer la section nommée &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/inifile.cpp" line="177"/>
        <source>Invalid key index</source>
        <translation>Index de clef incorrect</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/inifile.cpp" line="200"/>
        <source>Cannot delete key named &quot;%1&quot;</source>
        <translation>Impossible de supprimer la clef nommée &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>Code::Registry</name>
    <message>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="71"/>
        <source>Unable to open the key</source>
        <translation>Impossible d&apos;ouvrir la clef</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="90"/>
        <source>Unable to create the key</source>
        <translation>Impossible de créer la clef</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="115"/>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="123"/>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="138"/>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="145"/>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="154"/>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="157"/>
        <source>Cannot set the value data</source>
        <translation>Impossible de changer les données de la valeur</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="176"/>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="188"/>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="206"/>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="235"/>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="250"/>
        <source>Cannot find the value to read</source>
        <translation>Impossible de trouver la valeur à lire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="259"/>
        <source>Invalid value type</source>
        <translation>Type de valeur incorrect</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="279"/>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="321"/>
        <source>Unable to query informations about this key</source>
        <translation>Impossible de récupérer des informations à propos de cette clef</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="355"/>
        <location filename="../actions/actionpackdata/code/registry.cpp" line="460"/>
        <source>Unable to delete the key</source>
        <translation>Impossible de supprimer la clef</translation>
    </message>
</context>
<context>
    <name>Code::Sql</name>
    <message>
        <location filename="../actions/actionpackdata/code/sql.cpp" line="38"/>
        <source>Please specify the database driver that should be used</source>
        <translation>Merci de spécifier le pilote de base de données à utiliser</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/sql.cpp" line="117"/>
        <location filename="../actions/actionpackdata/code/sql.cpp" line="124"/>
        <source>The requested database driver is not available</source>
        <translation>Ce pilote de base de données n&apos;est pas disponible</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/sql.cpp" line="161"/>
        <source>Unable to establish a connection to the database</source>
        <translation>Impossible d&apos;établir une connexion vers la base de données</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/sql.cpp" line="174"/>
        <source>Failed to prepare the query</source>
        <translation>Impossible de préparer la requête</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/sql.cpp" line="200"/>
        <source>Failed to execute the query : %1</source>
        <translation>Impossible d&apos;exécuter la requête : %1</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/sql.cpp" line="211"/>
        <source>Cannot fetch the result of a non-select query</source>
        <translation>Impossible de récupérer le résultat d&apos;une requête non-select</translation>
    </message>
</context>
<context>
    <name>Code::Tcp</name>
    <message>
        <location filename="../actions/actionpackdata/code/tcp.cpp" line="106"/>
        <source>Cannot establish a connection to the host</source>
        <translation>Impossible d&apos;établir une connexion vers l&apos;hôte</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/tcp.cpp" line="114"/>
        <source>Waiting for bytes written failed</source>
        <translation>Attente d&apos;écriture échouée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/tcp.cpp" line="122"/>
        <source>Waiting for ready read failed</source>
        <translation>Attente de lecture échouée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/tcp.cpp" line="130"/>
        <source>Waiting for disconnection failed</source>
        <translation>Attente de déconnexion échouée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/tcp.cpp" line="141"/>
        <location filename="../actions/actionpackdata/code/tcp.cpp" line="146"/>
        <location filename="../actions/actionpackdata/code/tcp.cpp" line="155"/>
        <source>Write failed</source>
        <translation>Écriture échouée</translation>
    </message>
</context>
<context>
    <name>Code::TcpServer</name>
    <message>
        <location filename="../actions/actionpackdata/code/tcpserver.cpp" line="71"/>
        <source>Unable to start listening</source>
        <translation>Impossible de démarrer l&apos;écoute</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/tcpserver.cpp" line="79"/>
        <source>Waiting for new connection failed</source>
        <translation>Attente de nouvelle connexion échouée</translation>
    </message>
    <message>
        <source>Waiting for bytes written failed</source>
        <translation type="obsolete">Attente d&apos;écriture échouée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/tcpserver.cpp" line="89"/>
        <source>There is no pending connection</source>
        <translation>Il n&apos;y a pas de connexion en attente</translation>
    </message>
</context>
<context>
    <name>Code::Udp</name>
    <message>
        <location filename="../actions/actionpackdata/code/udp.cpp" line="87"/>
        <source>Cannot establish a connection to the host</source>
        <translation>Impossible d&apos;établir une connexion vers l&apos;hôte</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/udp.cpp" line="95"/>
        <source>Waiting for ready read failed</source>
        <translation>Attente de lecture échouée</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/code/udp.cpp" line="106"/>
        <location filename="../actions/actionpackdata/code/udp.cpp" line="111"/>
        <location filename="../actions/actionpackdata/code/udp.cpp" line="120"/>
        <source>Write failed</source>
        <translation>Écriture échouée</translation>
    </message>
</context>
<context>
    <name>Code::Web</name>
    <message>
        <location filename="../actions/actionpackdata/code/web.cpp" line="103"/>
        <source>Unable to open the destination file</source>
        <translation>Impossible d&apos;écrire le fichier de destination</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../actions/actionpackdata/actions/copyfiledefinition.h" line="62"/>
        <source>Copy file</source>
        <translation>Copier fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/copyfiledefinition.h" line="65"/>
        <source>Copy a file</source>
        <translation>Copie un fichier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readbinaryfiledefinition.h" line="59"/>
        <source>Read binary file</source>
        <translation>Lire fichier binaire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readbinaryfiledefinition.h" line="62"/>
        <source>Read a binary file</source>
        <translation>Lire un fichier binaire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readclipboarddefinition.h" line="50"/>
        <source>Read clipboard</source>
        <translation>Lire presse-papier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readclipboarddefinition.h" line="53"/>
        <source>Read the clipboard contents</source>
        <translation>Lit le contenu du presse-papier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifiledefinition.h" line="69"/>
        <source>Read INI file</source>
        <translation>Lire fichier INI</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readinifiledefinition.h" line="72"/>
        <source>Read an entry in an INI file</source>
        <translation>Lire une entrée dans un fichier INI</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistrydefinition.h" line="69"/>
        <source>Read registry</source>
        <translation>Lire registre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readregistrydefinition.h" line="72"/>
        <source>Read an entry from the registry</source>
        <translation>Lire une entrée de la base registre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfiledefinition.h" line="85"/>
        <source>Read text file</source>
        <translation>Lire fichier texte</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfiledefinition.h" line="88"/>
        <source>Read a plain text file</source>
        <translation>Lire un fichier texte</translation>
    </message>
    <message>
        <source>Read the entire file</source>
        <translation type="obsolete">Lire le fichier entier</translation>
    </message>
    <message>
        <source>Read only a selection</source>
        <translation type="obsolete">Lire une sélection</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writebinaryfiledefinition.h" line="59"/>
        <source>Write binary file</source>
        <translation>Écrire fichier binaire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writebinaryfiledefinition.h" line="62"/>
        <source>Write to a binary file</source>
        <translation>Écrire vers un fichier binaire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeclipboarddefinition.h" line="50"/>
        <source>Write clipboard</source>
        <translation>Écrire presse-papier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeclipboarddefinition.h" line="53"/>
        <source>Set the clipboard contents</source>
        <translation>Change le contenu du presse-papier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeinifiledefinition.h" line="67"/>
        <source>Write INI file</source>
        <translation>Écrire fichier INI</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeinifiledefinition.h" line="70"/>
        <source>Write an entry in an INI file</source>
        <translation>Écrire une entrée dans un fichier INI</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeregistrydefinition.h" line="68"/>
        <source>Write registry</source>
        <translation>Écrire registre</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writeregistrydefinition.h" line="71"/>
        <source>Writes an entry to the registry</source>
        <translation>Écrire une entrée dans la base de registres</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writetextfiledefinition.h" line="65"/>
        <source>Write text file</source>
        <translation>Écrire fichier texte</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writetextfiledefinition.h" line="68"/>
        <source>Write a plain text file</source>
        <translation>Écrire vers un fichier texte</translation>
    </message>
    <message>
        <source>Overwrite any content</source>
        <translation type="obsolete">Écraser tout contenu</translation>
    </message>
    <message>
        <source>Append to the end</source>
        <translation type="obsolete">Ajouter à la fin</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="93"/>
        <source>Web download</source>
        <translation>Téléchargement Web</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloaddefinition.h" line="96"/>
        <source>Downloads data from the Web</source>
        <translation>Télécharge des données à partir du Web</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readenvironmentdefinition.h" line="70"/>
        <source>Read environment variable</source>
        <translation>Lire variable d&apos;environnement</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readenvironmentdefinition.h" line="73"/>
        <source>Read a single or multiple environment variables</source>
        <translation>Lit une ou plusieurs variables d&apos;environnement</translation>
    </message>
</context>
<context>
    <name>ReadEnvironmentVariableInstance::modes</name>
    <message>
        <location filename="../actions/actionpackdata/actions/readenvironmentinstance.cpp" line="33"/>
        <source>Read all</source>
        <translation>Tout lire</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readenvironmentinstance.cpp" line="33"/>
        <source>Read one</source>
        <translation>N&apos;en lire qu&apos;une</translation>
    </message>
</context>
<context>
    <name>ReadTextFileInstance::modes</name>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfileinstance.cpp" line="30"/>
        <source>Read the entire file</source>
        <translation>Lire le fichier entier</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/readtextfileinstance.cpp" line="30"/>
        <source>Read only a selection</source>
        <translation>Lire une sélection</translation>
    </message>
</context>
<context>
    <name>WebDownloadInstance::destinations</name>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloadinstance.cpp" line="32"/>
        <source>Variable</source>
        <translation>Variable</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/webdownloadinstance.cpp" line="33"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
</context>
<context>
    <name>WriteTextFileInstance::modes</name>
    <message>
        <location filename="../actions/actionpackdata/actions/writetextfileinstance.cpp" line="30"/>
        <source>Overwrite any content</source>
        <translation>Écraser tout contenu</translation>
    </message>
    <message>
        <location filename="../actions/actionpackdata/actions/writetextfileinstance.cpp" line="30"/>
        <source>Append to the end</source>
        <translation>Ajouter à la fin</translation>
    </message>
</context>
</TS>
